@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhrcfile.pl 2.16 01/08/26 02:25:20
+##	@(#) mhrcfile.pl 2.18 01/10/06 20:02:06
 ##  Author:
 ##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
@@ -273,7 +273,7 @@ sub read_resource_file {
 		last  if $line =~ /^\s*<\/icons\s*>/i;
 		next  if $line =~ /^\s*$/;
 		$line =~ s/\s//g;
-		($type, $url) = split(/:/,$line,2);
+		($type, $url) = split(/[;:]/,$line,2);
 		$type =~ tr/A-Z/a-z/;
 		$Icons{$type} = $url;
 	    }
@@ -905,6 +905,12 @@ sub read_resource_file {
 	    $TSLICEEND = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
+	if ($elem eq 'tslicelevels') {		# Level of slice threading
+	    if (($tmp = &get_elem_int($handle, $elem, 1)) ne '') {
+		$TSLICELEVELS = $tmp;
+	    }
+	    last FMTSW;
+	}
         if ($elem eq 'tslicesingletxt') {
           $TSLICESINGLETXT = &get_elem_content($handle, $elem, $chop);
           last FMTSW;
