@@ -1,15 +1,15 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) osinit.pl 2.4 99/07/13 00:46:45
+##	@(#) osinit.pl 2.6 01/09/17 22:09:27
 ##  Author:
-##      Earl Hood       mhonarc@pobox.com
+##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
 ##	A library for setting up a script based upon the OS the script
 ##	is running under.  The main routine defined is OSinit.  See
 ##	the routine for specific information.
 ##---------------------------------------------------------------------------##
 ##    MHonArc -- Internet mail-to-HTML converter
-##    Copyright (C) 1995-1999	Earl Hood, mhonarc@pobox.com
+##    Copyright (C) 1995-1999	Earl Hood, mhonarc@mhonarc.org
 ##
 ##    This program is free software; you can redistribute it and/or modify
 ##    it under the terms of the GNU General Public License as published by
@@ -65,6 +65,7 @@ sub OSinit {
     } elsif (($^O !~ /cygwin/i) &&
     	     (($^O =~ /mswin/i) ||
 	      ($^O =~ /\bdos\b/i) ||
+	      ($^O =~ /\bos2\b/i) ||
     	      (($tmp = $ENV{'COMSPEC'}) &&
 	       ($tmp =~ /^[a-zA-Z]:\\/) &&
 	       (-e $tmp))) ) {
@@ -84,7 +85,7 @@ sub OSinit {
     }
 
     ##	Store name of program
-    if ($MSDOS || $WINDOWS) {
+    if ($MSDOS) {
         $DIRSEPREX = "\\\\\\/";
     } else {
         ($DIRSEPREX = $DIRSEP) =~ s/(\W)/\\$1/g;
@@ -111,7 +112,7 @@ sub OSinit {
 ##
 sub OSis_absolute_path {
  
-    if ($MSDOS || $WINDOWS) {
+    if ($MSDOS) {
         return $_[0] =~ /^([a-z]:)?[\\\/]/i;
     }
     if ($MACOS) {               ## Not sure about Mac
